/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.vorgang.collaboration;

import org.springframework.context.ApplicationEventPublisher;
import org.springframework.stereotype.Service;

import de.ozgcloud.vorgang.vorgang.Vorgang;
import de.ozgcloud.vorgang.vorgang.VorgangHead;
import lombok.RequiredArgsConstructor;

@Service
@RequiredArgsConstructor
public class CollaborationService {

	private final CollaborationRepository collaborationRepository;
	private final ApplicationEventPublisher publisher;

	public Vorgang createCollaborationVorgang(CreateCollaborationVorgangRequest request) {
		var vorgang = collaborationRepository.save(buildCollaborationVorgang(request));
		// TODO: wieder aktivieren wenn OZG-6380 implementiert ist
		// publisher.publishEvent(new VorgangCreatedEvent(vorgang.getId()));
		return vorgang;
	}

	Vorgang buildCollaborationVorgang(CreateCollaborationVorgangRequest request) {
		var srcVorgang = request.getVorgang();
		return Vorgang.builder()
				.name(srcVorgang.getName())
				.nummer(srcVorgang.getNummer())
				.formEngineName(srcVorgang.getFormEngineName())
				.aktenzeichen(srcVorgang.getAktenzeichen())
				.header(getHeader(request))
				.eingangs(srcVorgang.getEingangs())
				.build();
	}

	VorgangHead getHeader(CreateCollaborationVorgangRequest request) {
		return request.getVorgang().getHeader().toBuilder()
				.collaborationLevel(request.getCollaborationLevel())
				.organisationsEinheitId(request.getZustaendigeStelle())
				.build();
	}
}
